@@ -143,7 +143,7 @@ async def run_executor(address: str, session_id: str, tmp_dir: str, package: str
 
     mainframe.subscribe(f"executor/{EXECUTOR_NAME}/run_block", execute_block)
     mainframe.subscribe(f"executor/{EXECUTOR_NAME}/run_service_block", execute_service_block)
-    mainframe.subscribe('report', report_message)
+    mainframe.add_report_callback(report_message)
     mainframe.subscribe(exit_report_topic(), service_exit)
     mainframe.subscribe(status_report_topic(), service_status)
 
@@ -179,7 +179,6 @@ async def run_executor(address: str, session_id: str, tmp_dir: str, package: str
                 service_store[service_hash] = "running"
             run_in_new_thread(run)
 
-        # FIXME: mqtt 不能在 subscribe 后立即 publish，需要修复。
         mainframe.subscribe(prepare_report_topic(params), lambda _: send_service_config(params, message))
 
         await process.wait()
